/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user;

import java.util.ArrayDeque;
import java.util.Deque;
import java.util.List;
import java.util.Objects;

import lombok.Builder;
import lombok.Getter;
import lombok.Singular;

@Builder
@Getter
class RoleHierarchy {

	private final String roleName;

	@Singular
	private List<RoleHierarchy> subRoles;

	public List<String> getFlattenedHierarchy(String roleName) {
		var subRoles = new ArrayDeque<String>();
		collectSubRoles(this, roleName, subRoles);
		return subRoles.stream().toList();
	}

	boolean collectSubRoles(RoleHierarchy role, String roleName, Deque<String> subRoles) {
		subRoles.addLast(role.getRoleName());
		if (Objects.equals(role.getRoleName(), roleName)) {
			return true;
		}
		for (var subRole : role.getSubRoles()) {
			if (collectSubRoles(subRole, roleName, subRoles)) {
				return true;
			}
		}
		subRoles.removeLast();
		return false;
	}

}
