/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user;

import java.util.List;

import de.ozgcloud.user.settings.UserSettingsResource;
import jakarta.enterprise.context.ApplicationScoped;
import jakarta.ws.rs.core.Link;

import io.quarkus.hal.HalCollectionWrapper;
import io.quarkus.hal.HalEntityWrapper;

@ApplicationScoped
public class UserProfileResourceAssembler {

	static final String REL_SETTINGS = "settings";
	static final String REL_SELF = "self";

	HalEntityWrapper toUserProfileResource(User user, String userManagerUrl) {
		var entityWrapper = new HalEntityWrapper(user);
		var userId = user.getId().toHexString();

		entityWrapper.addLinks(
				Link.fromUri(userManagerUrl + UserProfileResource.USER_PROFILE_RESOURCE_PATH_TEMPLATE).rel(REL_SELF).build(userId),
				Link.fromUri(userManagerUrl + UserSettingsResource.SETTINGS_LINK_PATTERN).rel(REL_SETTINGS).build(userId));

		return entityWrapper;
	}

	private static final String COLLECTION_NAME_TEMPLATE = "userProfileList";

	HalCollectionWrapper toUserProfileResourceList(List<User> users, String userManagerUrl) {
		List<HalEntityWrapper> userResources = users.stream().map(user -> toUserProfileResource(user, userManagerUrl)).toList();

		return new HalCollectionWrapper(userResources, COLLECTION_NAME_TEMPLATE,
				Link.fromUri(userManagerUrl + UserProfileResource.USERS_PATH).rel(REL_SELF).build());
	}
}