/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.common.callcontext;

import java.nio.charset.StandardCharsets;
import java.util.Collection;
import java.util.Optional;
import java.util.stream.Stream;
import java.util.stream.StreamSupport;

import io.grpc.Metadata;
import io.grpc.Metadata.Key;

// TODO move to a grpcUtil class in common
class GrpcUtil {

	public static Optional<String> getFromHeaders(String key, Metadata headers) {
		return Optional.ofNullable(headers.get(createKeyOf(key)))
				.map(GrpcUtil::toUtf8String);
	}

	public static Collection<String> getCollection(String key, Metadata headers) {
		return Optional.ofNullable(headers.getAll(createKeyOf(key)))
				.map(GrpcUtil::split)
				.orElseGet(Stream::empty)
				.map(GrpcUtil::toUtf8String)
				.toList();
	}

	public static Key<byte[]> createKeyOf(String key) {
		return Key.of(key, Metadata.BINARY_BYTE_MARSHALLER);
	}

	private static Stream<byte[]> split(Iterable<byte[]> vals) {
		return StreamSupport.stream(vals.spliterator(), false);
	}

	private static String toUtf8String(byte[] bytes) {
		return new String(bytes, StandardCharsets.UTF_8);
	}
}