/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.common.callcontext;

import java.io.IOException;

import jakarta.inject.Inject;
import jakarta.ws.rs.container.ContainerRequestContext;
import jakarta.ws.rs.container.ContainerRequestFilter;
import jakarta.ws.rs.container.PreMatching;
import jakarta.ws.rs.ext.Provider;

import de.ozgcloud.user.common.JwtUtil;

@Provider
@PreMatching
public class HttpSecurityFilter implements ContainerRequestFilter {

	@Inject
	CurrentCallContextUserService userService;

	@Inject
	JwtUtil jwtUtil;

	@Override
	public void filter(ContainerRequestContext requestContext) throws IOException {
		userService.setCallContextUser(buildCallContextUser());
	}

	CallContextUser buildCallContextUser() {
		return CallContextUser.builder()
				.authenticated(true)
				.userId(jwtUtil.getUserId())
				.userName(jwtUtil.getUserName())
				.email(jwtUtil.getEmail())
				.roles(jwtUtil.getUserRoles())
				.organisatorischeEinheitenIds(jwtUtil.getOrganisationsEinheitIds())
				.build();
	}
}