/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.common.errorhandling;

import de.ozgcloud.common.errorhandling.FunctionalErrorCode;
import lombok.Getter;

@Getter
public class ResourceNotFoundException extends FunctionalException {

	private static final long serialVersionUID = 1L;
	private static final String MESSAGE_TEMPLATE = "Resource '%s' with id '%s' not found.";

	private final String resourceName;
	private final transient Object id;

	public ResourceNotFoundException(Class<?> resource, Object id) {
		super(buildErrorCode(resource, id));

		this.resourceName = resource.getSimpleName();
		this.id = id;
	}

	private static FunctionalErrorCode buildErrorCode(Class<?> resource, Object id) {
		return () -> MESSAGE_TEMPLATE.formatted(resource.getSimpleName(), id.toString());
	}
}