/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.keycloak;

import org.keycloak.representations.idm.UserProfileMetadata;
import org.keycloak.representations.idm.UserRepresentation;

import com.fasterxml.jackson.annotation.JsonIgnore;

/**
 * This is a user representation which works with currently used Keycloak version 20.0.3 Because of Quarkus upgrade to 3.5.0 the keycloak admin client
 * was updated to 22.0.5. The reason for that is the new resteasy client based on Jakarata EE 10 (jakarta.ws.rs-api). Keycloak admin client 20 .0.3 is
 * based on Jersey (javax.ws.rs-api). What we do here is simple ignoring one field added in the newer version of Keycloak in order for entity to be
 * processable by the older version. Once Keycloak will be upgraded we can remove this class.
 *
 * The workaround was discussed with Quarkus team https://github.com/quarkusio/quarkus/discussions/36766
 */
class OlderUserRepresentation extends UserRepresentation {

	@JsonIgnore
	private UserProfileMetadata userProfileMetadata;

	public OlderUserRepresentation(UserRepresentation origin) {
		setAttributes(origin.getAttributes());
		setClientRoles(origin.getClientRoles());
		setEmail(origin.getEmail());
		setId(origin.getId());
		setCreatedTimestamp(origin.getCreatedTimestamp());
		setFirstName(origin.getFirstName());
		setLastName(origin.getLastName());
		setUsername(origin.getUsername());
		setAccess(origin.getAccess());
		setClientConsents(origin.getClientConsents());
		setCredentials(origin.getCredentials());
		setDisableableCredentialTypes(origin.getDisableableCredentialTypes());
		setEmailVerified(origin.isEmailVerified());
		setEnabled(origin.isEnabled());
		setFederatedIdentities(origin.getFederatedIdentities());
		setFederationLink(origin.getFederationLink());
		setGroups(origin.getGroups());
		setNotBefore(origin.getNotBefore());
		setOrigin(origin.getOrigin());
		setRealmRoles(origin.getRealmRoles());
		setRequiredActions(origin.getRequiredActions());
		setSelf(origin.getSelf());
		setServiceAccountClientId(origin.getServiceAccountClientId());
		setSocialLinks(origin.getSocialLinks());
		setTotp(origin.isEmailVerified());
	}
}
