/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.organisationseinheit;

import java.util.Collection;

import jakarta.inject.Inject;

import de.ozgcloud.user.grpc.organisationseinheit.GrpcGetSupportedOrganisationsEinheitenResponse;
import de.ozgcloud.user.grpc.organisationseinheit.OrganisationsEinheitServiceGrpc.OrganisationsEinheitServiceImplBase;
import io.grpc.stub.StreamObserver;
import io.quarkus.grpc.GrpcService;

@GrpcService
public class OrganisationsEinheitGrpcService extends OrganisationsEinheitServiceImplBase {

	@Inject
	OrganisationsEinheitService organisationsEinheitService;

	@Override
	public void getSupportedOrganisationsEinheiten(GrpcGetSupportedOrganisationsEinheitenRequest request,
			StreamObserver<GrpcGetSupportedOrganisationsEinheitenResponse> responseObserver) {
		var organisationsEinheitIds = organisationsEinheitService.findAllOrganisationsEinheitIds();
		var response = GrpcGetSupportedOrganisationsEinheitenResponse.newBuilder()
				.addAllOrganisationseinheiten(mapToGrpc(organisationsEinheitIds))
				.build();

		responseObserver.onNext(response);
		responseObserver.onCompleted();
	}

	private Collection<GrpcOrganisationsEinheit> mapToGrpc(Collection<String> organisationsEinheitIds) {
		return organisationsEinheitIds.stream().map(id -> GrpcOrganisationsEinheit.newBuilder().setOrganisationsEinheitId(id).build()).toList();
	}
}
