/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.recipient;

import java.util.Collection;

import jakarta.inject.Inject;

import de.ozgcloud.user.User;
import de.ozgcloud.user.grpc.recipient.GrpcFindRecipientRequest;
import de.ozgcloud.user.grpc.recipient.GrpcFindRecipientResponse;
import de.ozgcloud.user.grpc.recipient.RecipientServiceGrpc.RecipientServiceImplBase;
import io.grpc.stub.StreamObserver;
import io.quarkus.grpc.GrpcService;

@GrpcService
public class RecipientGrpcService extends RecipientServiceImplBase {

	@Inject
	RecipientService recipientService;
	@Inject
	RecipientMapper recipientMapper;

	@Override
	public void findRecipientByOrganisationsEinheitId(GrpcFindRecipientRequest request, StreamObserver<GrpcFindRecipientResponse> responseObserver) {
		var recipients = recipientService.findByOrganisationsEinheitId(request.getOrganisationsEinheitId());

		responseObserver.onNext(buildSearchReponse(recipients));
		responseObserver.onCompleted();
	}

	private GrpcFindRecipientResponse buildSearchReponse(Collection<User> recipients) {
		return GrpcFindRecipientResponse.newBuilder().addAllRecipient(recipients.stream().map(recipientMapper::toRecipient).toList()).build();
	}
}