/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.settings;

import java.util.Optional;

import org.bson.types.ObjectId;

import de.ozgcloud.common.logging.OzgCloudLogging;
import de.ozgcloud.user.User;
import io.quarkus.mongodb.panache.PanacheMongoRepository;
import jakarta.enterprise.context.ApplicationScoped;

@ApplicationScoped
@OzgCloudLogging
class UserSettingsRepository implements PanacheMongoRepository<User> {

	public Optional<UserSettings> updateByUserId(String userId, UserSettings userSettings) {
		return Optional.ofNullable(userId)
				.filter(ObjectId::isValid)
				.map(ObjectId::new)
				.flatMap(id -> findByIdOptional(id).map(user -> {
					user.setUserSettings(userSettings);
					update(user);
					return findById(user.getId()).getUserSettings();
				}));
	}
}