/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.settings;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import jakarta.ws.rs.core.Link;

import org.apache.commons.lang3.StringUtils;

import de.ozgcloud.user.UserRole;
import de.ozgcloud.user.common.callcontext.CallContextUser;
import de.ozgcloud.user.common.callcontext.CurrentCallContextUserService;
import io.quarkus.hal.HalEntityWrapper;

@ApplicationScoped
class UserSettingsResourceAssembler {

	static final String REL_SELF = "self";
	static final String REL_EDIT = "edit";

	@Inject
	CurrentCallContextUserService currentUserService;

	HalEntityWrapper toResource(UserSettings setting, String userId, String userManagerUrl) {
		var entityWrapper = new HalEntityWrapper(setting);

		entityWrapper.addLinks(Link.fromUri(userManagerUrl + UserSettingsResource.SETTINGS_LINK_PATTERN).rel(REL_SELF).build(userId));

		if (isUserAuthorized()) {
			entityWrapper.addLinks(Link.fromUri(userManagerUrl + UserSettingsResource.SETTINGS_LINK_PATTERN).rel(REL_EDIT).build(userId));
		}

		return entityWrapper;
	}

	boolean isUserAuthorized() {
		return hasValidEmail() && hasVerwaltungUserRole();
	}

	boolean hasValidEmail() {
		return currentUserService.getCurrentCallContextUser().map(CallContextUser::getEmail).filter(StringUtils::isNotEmpty).isPresent();
	}

	boolean hasVerwaltungUserRole() {
		return currentUserService.hasRole(UserRole.VERWALTUNG_USER);
	}
}