/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.userprofile;

import java.util.stream.Stream;

import jakarta.inject.Inject;

import de.ozgcloud.user.User;
import de.ozgcloud.user.UserService;
import de.ozgcloud.user.grpc.userprofile.UserProfileServiceGrpc.UserProfileServiceImplBase;
import io.grpc.stub.StreamObserver;
import io.quarkus.grpc.GrpcService;

@GrpcService
public class UserProfileGrpcService extends UserProfileServiceImplBase {

	@Inject
	UserService service;

	@Inject
	UserProfileMapper mapper;

	@Override
	public void getById(GrpcGetUserProfileRequest request, StreamObserver<GrpcGetUserProfileResponse> responseObserver) {
		var userProfile = service.getById(request.getUserId());

		responseObserver.onNext(buildResponse(userProfile));
		responseObserver.onCompleted();
	}

	private GrpcGetUserProfileResponse buildResponse(User userProfile) {
		return GrpcGetUserProfileResponse.newBuilder().setUserProfile(mapper.mapTo(userProfile)).build();
	}

	@Override
	public void getByExternalId(GrpcGetUserProfileRequest request, StreamObserver<GrpcGetUserProfileResponse> responseObserver) {
		var userProfile = service.findByExternalId(request.getUserId());

		responseObserver.onNext(buildResponse(userProfile));
		responseObserver.onCompleted();
	}

	@Override
	public void findInactiveUserIds(GrpcFindInactiveUserIdsRequest request, StreamObserver<GrpcFindInactiveUserIdsResponse> responseObserver) {
		var userIds = service.findAllInactiveUserIds();

		responseObserver.onNext(buildGrpcGetInactiveUserIdsResponse(userIds));
		responseObserver.onCompleted();
	}

	GrpcFindInactiveUserIdsResponse buildGrpcGetInactiveUserIdsResponse(Stream<String> userIds) {
		return GrpcFindInactiveUserIdsResponse.newBuilder()
				.addAllUserProfileIds(userIds.map(id -> GrpcUserProfileId.newBuilder().setId(id).build())::iterator)
				.build();
	}

	@Override
	public void deleteInactiveUser(GrpcDeleteInactiveUserRequest request, StreamObserver<GrpcDeleteInactiveUserResponse> responseObserver) {
		service.deleteInactive(request.getUserId());

		responseObserver.onNext(GrpcDeleteInactiveUserResponse.newBuilder().build());
		responseObserver.onCompleted();
	}
}