/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.common.callcontext;

import io.grpc.CallOptions;
import io.grpc.Channel;
import io.grpc.ClientCall;
import io.grpc.ClientInterceptor;
import io.grpc.ForwardingClientCall.SimpleForwardingClientCall;
import io.grpc.Metadata;
import io.grpc.MethodDescriptor;

public class CallContextInterceptorTestFactory {

	private static final String CLIENT_NAME = "Client - Alfa";
	private static final String ORGANISATIONS_EINHEIT_ID = "organisationsEinheitId";
	private static final Boolean ORGANISATIONS_EINEHIT_ID_CHECK_NECESSARY = Boolean.TRUE;

	public static ClientInterceptor createClientInterceptor() {
		return new TestClientInterceptor();
	}

	private static class TestClientInterceptor implements ClientInterceptor {

		@Override
		public <ReqT, RespT> ClientCall<ReqT, RespT> interceptCall(MethodDescriptor<ReqT, RespT> method, CallOptions callOptions, Channel next) {
			return new TestCallContextAttachingClientCall<>(next.newCall(method, callOptions));
		}

		final class TestCallContextAttachingClientCall<ReqT, RespT> extends SimpleForwardingClientCall<ReqT, RespT> {

			protected TestCallContextAttachingClientCall(ClientCall<ReqT, RespT> delegate) {
				super(delegate);
			}

			@Override
			public void start(Listener<RespT> responseListener, Metadata headers) {
				headers.merge(new Metadata());

				super.start(responseListener, headers);
			}
		}
	}

	public static ClientInterceptor createClientInterceptorWithMetadata() {
		return new TestClientInterceptorWithMetadata();
	}

	private static class TestClientInterceptorWithMetadata implements ClientInterceptor {

		@Override
		public <ReqT, RespT> ClientCall<ReqT, RespT> interceptCall(MethodDescriptor<ReqT, RespT> method, CallOptions callOptions, Channel next) {
			return new TestCallContextAttachingClientCall<>(next.newCall(method, callOptions));
		}

		final class TestCallContextAttachingClientCall<ReqT, RespT> extends SimpleForwardingClientCall<ReqT, RespT> {
			protected TestCallContextAttachingClientCall(ClientCall<ReqT, RespT> delegate) {
				super(delegate);
			}

			@Override
			public void start(Listener<RespT> responseListener, Metadata headers) {
				headers.merge(createMetadata());

				super.start(responseListener, headers);
			}

			private Metadata createMetadata() {
				var metadata = new Metadata();
				metadata.put(GrpcUtil.createKeyOf(GrpcCallContextInterceptor.KEY_CLIENT_NAME),
						CLIENT_NAME.getBytes());
				metadata.put(GrpcUtil.createKeyOf(GrpcCallContextInterceptor.KEY_ACCESS_LIMITED_ORGAID),
						ORGANISATIONS_EINHEIT_ID.getBytes());
				metadata.put(GrpcUtil.createKeyOf(GrpcCallContextInterceptor.KEY_ACCESS_LIMITED),
						ORGANISATIONS_EINEHIT_ID_CHECK_NECESSARY.toString().getBytes());
				return metadata;
			}
		}
	}
}