/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.common.callcontext;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

import io.grpc.Metadata;

class GrpcUtilTest {

	private static final String KEY_STR = "dummy-bin";
	private static final String VALUE_STR = "dummyKeyValueWithöäü#!,.-?";

	@DisplayName("Create key of")
	@Nested
	class TestCreateKeyOf {

		@Test
		void shouldReturnKey() {
			var key = GrpcUtil.createKeyOf(KEY_STR);

			assertThat(key.originalName()).isEqualTo(KEY_STR);
			assertThat(key.name()).isEqualTo(KEY_STR);
		}
	}

	@DisplayName("Get from headers")
	@Nested
	class TestGetFromHeaders {

		@Test
		void shouldReturnValueIfExists() {
			var value = GrpcUtil.getFromHeaders(KEY_STR, createMetadata());

			assertThat(value).isPresent();
			assertThat(value.get()).contains(VALUE_STR);
		}

		@Test
		void shouldReturnEmptyIfNotExists() {
			var value = GrpcUtil.getFromHeaders(KEY_STR, new Metadata());

			assertThat(value).isEmpty();
		}
	}

	@DisplayName("Get collection")
	@Nested
	class TestGetCollection {

		@Test
		void shouldReturnSingleValueAsList() {
			var valueList = GrpcUtil.getCollection(KEY_STR, createMetadata());

			assertThat(valueList).containsExactly(VALUE_STR);
		}

		@Test
		void shouldReturnMultipleValuesAsList() {
			var metadata = createMetadata();
			metadata.put(GrpcUtil.createKeyOf(KEY_STR), "otherValue-bin".getBytes());

			var valueList = GrpcUtil.getCollection(KEY_STR, metadata);

			assertThat(valueList).containsExactly(VALUE_STR, "otherValue-bin");
		}

		@Test
		void shouldReturnEmptyListIfNotExists() {
			var valueList = GrpcUtil.getCollection(KEY_STR, new Metadata());

			assertThat(valueList).isEmpty();
		}
	}

	private Metadata createMetadata() {
		var metadata = new Metadata();
		metadata.put(GrpcUtil.createKeyOf(KEY_STR), VALUE_STR.getBytes());
		return metadata;
	}
}
