/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.common.lock;

import static org.assertj.core.api.Assertions.*;

import java.time.Instant;
import java.time.temporal.ChronoUnit;

import jakarta.inject.Inject;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import de.ozgcloud.user.common.MongoDbTestProfile;
import io.quarkus.test.junit.QuarkusTest;
import io.quarkus.test.junit.TestProfile;

@QuarkusTest
@TestProfile(MongoDbTestProfile.class)
class LockRepositoryITCase {

	@Inject
	LockRepository repository;

	private final Lock lock = LockTestFactory.create();

	@BeforeEach
	void init() {
		repository.deleteAll();
	}

	@Test
	void shouldSave() {
		repository.persist(lock);

		assertThat(repository.count()).isEqualTo(1L);
	}

	@Test
	void shouldFindLockBefore() {
		var lock = Lock.builder().timestamp(Instant.now().minus(1, ChronoUnit.HOURS).toEpochMilli()).build();
		repository.persist(lock);

		var savedLock = repository.findLockBefore(Instant.now());

		assertThat(savedLock).isPresent();
		assertThat(savedLock.get()).usingRecursiveComparison().ignoringFields("id").isEqualTo(lock);
	}

	@Test
	void shouldFindLock() {
		repository.persist(lock);

		var savedLock = repository.findLock(Instant.ofEpochMilli(lock.getTimestamp()));

		assertThat(savedLock).isPresent();
		assertThat(savedLock.get()).usingRecursiveComparison().ignoringFields("id").isEqualTo(lock);
	}
}
