/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.common.lock;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.time.Instant;
import java.util.Optional;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;
import org.mockito.Spy;

import io.quarkus.mongodb.panache.PanacheQuery;

class LockRepositoryTest {
	@Spy
	LockRepository lockRepository;

	@Mock
	PanacheQuery<Lock> panacheFindQuery;

	@DisplayName("Test loading sync lock")
	@Nested
	class TestGetLock {
		private static final Lock LOCK = LockTestFactory.create();

		@BeforeEach
		void init() {
			doReturn(panacheFindQuery).when(lockRepository).find(anyString(), anyLong());
			doReturn(Optional.of(LOCK)).when(panacheFindQuery).firstResultOptional();
		}

		@Test
		void shouldGetOldLock() {
			var lockOptional = lockRepository.findLockBefore(Instant.ofEpochMilli(LOCK.getTimestamp()));

			assertThat(lockOptional).isPresent().get().hasFieldOrPropertyWithValue(Lock.TIMESTAMP_FIELD, LOCK.getTimestamp());
		}

		@Test
		void shouldGetLock() {
			var lockOptional = lockRepository.findLock(Instant.ofEpochMilli(LOCK.getTimestamp()));

			assertThat(lockOptional).isPresent().get().hasFieldOrPropertyWithValue(Lock.TIMESTAMP_FIELD, LOCK.getTimestamp());
		}
	}
}
