/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.keycloak;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.lang.reflect.Field;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import lombok.SneakyThrows;

class KeycloakProviderTest {

	@InjectMocks
	KeycloakProvider keycloakProvider;
	@Mock
	KeycloakApiProperties properties;

	@DisplayName("Test providing keycloak admin client")
	@Nested
	class TestProvider {
		@BeforeEach
		void initProperties() {
			setServerUrl();
			when(properties.realm()).thenReturn("realm");
			when(properties.user()).thenReturn("user");
			when(properties.password()).thenReturn("password");
		}

		@SneakyThrows
		private void setServerUrl() {
			Field url = keycloakProvider.getClass().getDeclaredField("keycloakUrl");
			url.set(keycloakProvider, "url");
		}

		@Test
		void shouldCreateRealmResource() {
			var resource = keycloakProvider.provide();

			assertThat(resource).isNotNull();
		}
	}
}
