/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.organisationseinheit;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.bson.conversions.Bson;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;
import org.mockito.Spy;

import com.mongodb.client.DistinctIterable;
import com.mongodb.client.MongoCollection;
import com.mongodb.client.MongoCursor;
import com.mongodb.client.model.Filters;

import de.ozgcloud.user.User;

class OrganisationsEinheitRepositoryTest {

	@Spy
	private OrganisationsEinheitRepository organisationsEinheitRepository;

	@DisplayName("Test find Organisationseinheiten Ids")
	@Nested
	class TestFindOrganisationsEinheitIds {
		@Mock
		private MongoCollection<?> mongoCollection;
		@Mock
		private MongoCursor<String> mongoCursor;

		@Test
		void shouldFindAllOrganisationsEinheitIds() {
			var iterable = mock(DistinctIterable.class);
			when(iterable.iterator()).thenReturn(mongoCursor);
			doReturn(mongoCollection).when(organisationsEinheitRepository).mongoCollection();
			when(mongoCollection.distinct(anyString(), any(Bson.class), any())).thenReturn(iterable);

			organisationsEinheitRepository.findAllOrganisationsEinheitIds();

			verify(mongoCollection).distinct(User.ORGANISATIONS_EINHEIT_IDS_FIELD, Filters.eq(User.DELETED_FIELD, false), String.class);
		}
	}

}