/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.recipient;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.util.List;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.user.UserTestFactory;
import de.ozgcloud.user.grpc.recipient.GrpcFindRecipientResponse;
import io.grpc.stub.StreamObserver;

class RecipientGrpcServiceTest {

	@InjectMocks
	RecipientGrpcService recipientGrpcService;
	@Mock
	RecipientService recipientService;
	@Mock
	RecipientMapper recipientMapper;

	@DisplayName("Find recipient by organisationsEinheitId")
	@Nested
	class TestFindRecipientByOrganisationsEinheitId {

		@Mock
		private StreamObserver<GrpcFindRecipientResponse> streamObserver;

		@BeforeEach
		void init() {
			when(recipientMapper.toRecipient(any())).thenReturn(RecipientTestFactory.create());
		}

		@Test
		void shouldGetUsersFromRepository() {
			when(recipientService.findByOrganisationsEinheitId(any())).thenReturn(List.of(UserTestFactory.create()));

			recipientGrpcService.findRecipientByOrganisationsEinheitId(RecipientTestFactory.FIND_REQUEST, streamObserver);

			verify(recipientService).findByOrganisationsEinheitId(UserTestFactory.ORGANISTATIONSEINHEITEN_ID);
		}
	}
}