/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.recipient;

import static org.assertj.core.api.Assertions.*;

import org.apache.commons.lang3.StringUtils;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.user.UserTestFactory;

class RecipientMapperTest {

	private RecipientMapper mapper = Mappers.getMapper(RecipientMapper.class);

	@DisplayName("Map to recipient")
	@Nested
	class TestToRecipient {

		@Test
		void shouldMapFirstName() {
			var recipient = mapper.toRecipient(UserTestFactory.create());

			assertThat(recipient.getFirstName()).isEqualTo(UserTestFactory.FIRST_NAME);
		}

		@Test
		void shouldMapLastName() {
			var recipient = mapper.toRecipient(UserTestFactory.create());

			assertThat(recipient.getLastName()).isEqualTo(UserTestFactory.LAST_NAME);
		}

		@Test
		void shouldMapEmail() {
			var recipient = mapper.toRecipient(UserTestFactory.create());

			assertThat(recipient.getEmail()).isEqualTo(UserTestFactory.EMAIL);
		}

		@Test
		void shouldMapNullAsEmptyString() {
			var recipient = mapper.toRecipient(UserTestFactory.createBuilder().email(null).build());

			assertThat(recipient.getEmail()).isEqualTo(StringUtils.EMPTY);
		}

		@Test
		void shouldNotThrowExceptionOnNull() {
			Assertions.assertDoesNotThrow(() -> mapper.toRecipient(null));
		}
	}
}