/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.recipient;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import com.cronutils.utils.StringUtils;

import de.ozgcloud.user.UserTestFactory;
import de.ozgcloud.user.common.errorhandling.FunctionalException;

class RecipientServiceTest {

	@InjectMocks
	RecipientService service;
	@Mock
	RecipientRepository repository;

	@DisplayName("Find by organisationsEinheitId")
	@Nested
	class TestFindByOrganisationsEinheitId {

		private static final String EXPECTED_EXCEPTION_MESSAGE_TEMPLATE = "Functional error: "
				+ RecipientService.MISSING_ORGANISATIONS_EINHEIT_ID_MESSAGE_TEMPLATE;

		@Test
		void shouldThrowExceptionOnNullId() {
			var expectedMessage = String.format(EXPECTED_EXCEPTION_MESSAGE_TEMPLATE, "null");

			assertThatExceptionOfType(FunctionalException.class)
					.isThrownBy(() -> service.findByOrganisationsEinheitId(null))
					.withMessageStartingWith(expectedMessage);
		}

		@Test
		void shouldThrowExceptionOnEmptyId() {
			var expectedMessage = String.format(EXPECTED_EXCEPTION_MESSAGE_TEMPLATE, StringUtils.EMPTY);

			assertThatExceptionOfType(FunctionalException.class)
					.isThrownBy(() -> service.findByOrganisationsEinheitId(StringUtils.EMPTY))
					.withMessageStartingWith(expectedMessage);
		}

		@Test
		void shouldCallRepository() {
			service.findByOrganisationsEinheitId(UserTestFactory.ORGANISTATIONSEINHEITEN_ID);

			verify(repository).findByOrganisationsEinheitId(UserTestFactory.ORGANISTATIONSEINHEITEN_ID);
		}
	}
}