/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.settings;

import static de.ozgcloud.user.settings.UserSettings.*;
import static de.ozgcloud.user.settings.UserSettingsResource.*;
import static io.restassured.RestAssured.*;
import static org.hamcrest.CoreMatchers.*;

import de.ozgcloud.user.TestDatabaseUtils;
import jakarta.inject.Inject;
import jakarta.ws.rs.core.MediaType;

import org.apache.http.HttpStatus;
import org.eclipse.microprofile.jwt.JsonWebToken;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import com.mongodb.client.MongoClient;

import de.ozgcloud.user.UserService;
import de.ozgcloud.user.UserTestFactory;
import io.quarkus.test.junit.QuarkusTest;
import io.quarkus.test.junit.TestProfile;

@QuarkusTest
@TestProfile(UserSettingsResourceTestProfile.class)
class UserSettingsResourceITCase {

	private static final String USER_MANAGER_URL = "http://localhost:9092";

	@Inject
	JsonWebToken jwt;

	@Inject
	UserService userService;

	@Inject
	MongoClient mongoClient;

	private String userId;

	@BeforeEach
	void init() {
		var mongoDb = TestDatabaseUtils.getDatabase(mongoClient);
		mongoDb.getCollection("User").drop();

		var user = UserTestFactory.createBuilder()
				.externalId(jwt.getSubject())
				.keycloakUserId(jwt.getSubject())
				.userSettings(new UserSettings(NotificationsSendFor.ALL)).build();
		var savedUser = userService.save(user);

		userId = savedUser.getId().toHexString();
	}

	@Test
	void shouldGetUserSettings() {
		given()
				.when()
				.accept(MediaType.APPLICATION_JSON)
				.get(SETTINGS_LINK_PATTERN, userId)
				.then()
				.statusCode(HttpStatus.SC_OK)
				.body(NOTIFICATIONS_SEND_FOR_FIELD, is(NotificationsSendFor.ALL.name()))
				.body("_links.self.href", is(USER_MANAGER_URL + SETTINGS_LINK_PATTERN.replace("{id}", userId)));
	}

	@Test
	void shouldUpdateUserSettings() {
		given()
				.pathParam("id", userId)
				.contentType(MediaType.APPLICATION_JSON)
				.body(UserSettingsTestFactory.create())
				.when()
				.patch(SETTINGS_LINK_PATTERN)
				.then()
				.statusCode(HttpStatus.SC_OK)
				.body(NOTIFICATIONS_SEND_FOR_FIELD, is(NotificationsSendFor.NONE.name()))
				.body("_links.self.href", is(USER_MANAGER_URL + SETTINGS_LINK_PATTERN.replace("{id}", userId)));
	}
}