/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.userprofile;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.user.User;
import de.ozgcloud.user.UserTestFactory;

class UserProfileMapperTest {

	private UserProfileMapper mapper = Mappers.getMapper(UserProfileMapper.class);

	@DisplayName("Map to")
	@Nested
	class TestMapTo {

		@Test
		void shouldMapFirstName() {
			var userProfile = map();

			assertThat(userProfile.getFirstName()).isEqualTo(UserTestFactory.FIRST_NAME);
		}

		@Test
		void shouldMapLastName() {
			var userProfile = map();

			assertThat(userProfile.getLastName()).isEqualTo(UserTestFactory.LAST_NAME);
		}

		@Test
		void shouldMapEMail() {
			var userProfile = map();

			assertThat(userProfile.getEmail()).isEqualTo(UserTestFactory.EMAIL);
		}

		@Test
		void shouldMapId() {
			var userProfile = map();

			assertThat(userProfile.getId()).isEqualTo(UserTestFactory.ID.toString());
		}

		private GrpcUserProfile map() {
			return mapper.mapTo(UserTestFactory.create());
		}

		@Test
		void shouldProceedWithNull() {
			Assertions.assertDoesNotThrow(() -> mapper.mapTo(User.builder().build()));
		}
	}
}